/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_AALOGPARSE_GRAMMAR_H_INCLUDED
# define YY_AALOGPARSE_GRAMMAR_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int aalogparse_debug;
#endif
/* "%code requires" blocks.  */
#line 21 "grammar.y"

	#include <aalogparse.h>

#line 53 "grammar.h"

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    TOK_DIGITS = 258,              /* TOK_DIGITS  */
    TOK_TYPE_UNKNOWN = 259,        /* TOK_TYPE_UNKNOWN  */
    TOK_QUOTED_STRING = 260,       /* TOK_QUOTED_STRING  */
    TOK_ID = 261,                  /* TOK_ID  */
    TOK_MODE = 262,                /* TOK_MODE  */
    TOK_DMESG_STAMP = 263,         /* TOK_DMESG_STAMP  */
    TOK_AUDIT_DIGITS = 264,        /* TOK_AUDIT_DIGITS  */
    TOK_DATE_MONTH = 265,          /* TOK_DATE_MONTH  */
    TOK_DATE = 266,                /* TOK_DATE  */
    TOK_TIME = 267,                /* TOK_TIME  */
    TOK_HEXSTRING = 268,           /* TOK_HEXSTRING  */
    TOK_TYPE_OTHER = 269,          /* TOK_TYPE_OTHER  */
    TOK_MSG_REST = 270,            /* TOK_MSG_REST  */
    TOK_IP_ADDR = 271,             /* TOK_IP_ADDR  */
    TOK_EQUALS = 272,              /* TOK_EQUALS  */
    TOK_COLON = 273,               /* TOK_COLON  */
    TOK_MINUS = 274,               /* TOK_MINUS  */
    TOK_OPEN_PAREN = 275,          /* TOK_OPEN_PAREN  */
    TOK_CLOSE_PAREN = 276,         /* TOK_CLOSE_PAREN  */
    TOK_PERIOD = 277,              /* TOK_PERIOD  */
    TOK_QUESTION_MARK = 278,       /* TOK_QUESTION_MARK  */
    TOK_SINGLE_QUOTE = 279,        /* TOK_SINGLE_QUOTE  */
    TOK_NONE = 280,                /* TOK_NONE  */
    TOK_TYPE_REJECT = 281,         /* TOK_TYPE_REJECT  */
    TOK_TYPE_AUDIT = 282,          /* TOK_TYPE_AUDIT  */
    TOK_TYPE_COMPLAIN = 283,       /* TOK_TYPE_COMPLAIN  */
    TOK_TYPE_HINT = 284,           /* TOK_TYPE_HINT  */
    TOK_TYPE_STATUS = 285,         /* TOK_TYPE_STATUS  */
    TOK_TYPE_ERROR = 286,          /* TOK_TYPE_ERROR  */
    TOK_TYPE_AA_REJECT = 287,      /* TOK_TYPE_AA_REJECT  */
    TOK_TYPE_AA_AUDIT = 288,       /* TOK_TYPE_AA_AUDIT  */
    TOK_TYPE_AA_COMPLAIN = 289,    /* TOK_TYPE_AA_COMPLAIN  */
    TOK_TYPE_AA_HINT = 290,        /* TOK_TYPE_AA_HINT  */
    TOK_TYPE_AA_STATUS = 291,      /* TOK_TYPE_AA_STATUS  */
    TOK_TYPE_AA_ERROR = 292,       /* TOK_TYPE_AA_ERROR  */
    TOK_TYPE_LSM_AVC = 293,        /* TOK_TYPE_LSM_AVC  */
    TOK_TYPE_USER_AVC = 294,       /* TOK_TYPE_USER_AVC  */
    TOK_KEY_APPARMOR = 295,        /* TOK_KEY_APPARMOR  */
    TOK_KEY_TYPE = 296,            /* TOK_KEY_TYPE  */
    TOK_KEY_MSG = 297,             /* TOK_KEY_MSG  */
    TOK_KEY_OPERATION = 298,       /* TOK_KEY_OPERATION  */
    TOK_KEY_NAME = 299,            /* TOK_KEY_NAME  */
    TOK_KEY_NAME2 = 300,           /* TOK_KEY_NAME2  */
    TOK_KEY_MASK = 301,            /* TOK_KEY_MASK  */
    TOK_KEY_DENIED_MASK = 302,     /* TOK_KEY_DENIED_MASK  */
    TOK_KEY_REQUESTED_MASK = 303,  /* TOK_KEY_REQUESTED_MASK  */
    TOK_KEY_ATTRIBUTE = 304,       /* TOK_KEY_ATTRIBUTE  */
    TOK_KEY_TASK = 305,            /* TOK_KEY_TASK  */
    TOK_KEY_PARENT = 306,          /* TOK_KEY_PARENT  */
    TOK_KEY_MAGIC_TOKEN = 307,     /* TOK_KEY_MAGIC_TOKEN  */
    TOK_KEY_INFO = 308,            /* TOK_KEY_INFO  */
    TOK_KEY_PEER_INFO = 309,       /* TOK_KEY_PEER_INFO  */
    TOK_KEY_PID = 310,             /* TOK_KEY_PID  */
    TOK_KEY_PEER_PID = 311,        /* TOK_KEY_PEER_PID  */
    TOK_KEY_PROFILE = 312,         /* TOK_KEY_PROFILE  */
    TOK_KEY_PEER_PROFILE = 313,    /* TOK_KEY_PEER_PROFILE  */
    TOK_KEY_LABEL = 314,           /* TOK_KEY_LABEL  */
    TOK_KEY_PEER_LABEL = 315,      /* TOK_KEY_PEER_LABEL  */
    TOK_KEY_PEER = 316,            /* TOK_KEY_PEER  */
    TOK_AUDIT = 317,               /* TOK_AUDIT  */
    TOK_KEY_FAMILY = 318,          /* TOK_KEY_FAMILY  */
    TOK_KEY_SOCK_TYPE = 319,       /* TOK_KEY_SOCK_TYPE  */
    TOK_KEY_PROTOCOL = 320,        /* TOK_KEY_PROTOCOL  */
    TOK_KEY_NAMESPACE = 321,       /* TOK_KEY_NAMESPACE  */
    TOK_KEY_ERROR = 322,           /* TOK_KEY_ERROR  */
    TOK_KEY_FSUID = 323,           /* TOK_KEY_FSUID  */
    TOK_KEY_FSUID_UPPER = 324,     /* TOK_KEY_FSUID_UPPER  */
    TOK_KEY_OUID = 325,            /* TOK_KEY_OUID  */
    TOK_KEY_OUID_UPPER = 326,      /* TOK_KEY_OUID_UPPER  */
    TOK_KEY_UID = 327,             /* TOK_KEY_UID  */
    TOK_KEY_AUID = 328,            /* TOK_KEY_AUID  */
    TOK_KEY_SAUID = 329,           /* TOK_KEY_SAUID  */
    TOK_KEY_SES = 330,             /* TOK_KEY_SES  */
    TOK_KEY_HOSTNAME = 331,        /* TOK_KEY_HOSTNAME  */
    TOK_KEY_ADDR = 332,            /* TOK_KEY_ADDR  */
    TOK_KEY_TERMINAL = 333,        /* TOK_KEY_TERMINAL  */
    TOK_KEY_EXE = 334,             /* TOK_KEY_EXE  */
    TOK_KEY_COMM = 335,            /* TOK_KEY_COMM  */
    TOK_KEY_CAPABILITY = 336,      /* TOK_KEY_CAPABILITY  */
    TOK_KEY_CAPNAME = 337,         /* TOK_KEY_CAPNAME  */
    TOK_KEY_OFFSET = 338,          /* TOK_KEY_OFFSET  */
    TOK_KEY_TARGET = 339,          /* TOK_KEY_TARGET  */
    TOK_KEY_LADDR = 340,           /* TOK_KEY_LADDR  */
    TOK_KEY_FADDR = 341,           /* TOK_KEY_FADDR  */
    TOK_KEY_LPORT = 342,           /* TOK_KEY_LPORT  */
    TOK_KEY_FPORT = 343,           /* TOK_KEY_FPORT  */
    TOK_KEY_BUS = 344,             /* TOK_KEY_BUS  */
    TOK_KEY_PATH = 345,            /* TOK_KEY_PATH  */
    TOK_KEY_INTERFACE = 346,       /* TOK_KEY_INTERFACE  */
    TOK_KEY_MEMBER = 347,          /* TOK_KEY_MEMBER  */
    TOK_KEY_SIGNAL = 348,          /* TOK_KEY_SIGNAL  */
    TOK_KEY_FSTYPE = 349,          /* TOK_KEY_FSTYPE  */
    TOK_KEY_FLAGS = 350,           /* TOK_KEY_FLAGS  */
    TOK_KEY_SRCNAME = 351,         /* TOK_KEY_SRCNAME  */
    TOK_KEY_UNIX_PEER_ADDR = 352,  /* TOK_KEY_UNIX_PEER_ADDR  */
    TOK_KEY_EXECPATH = 353,        /* TOK_KEY_EXECPATH  */
    TOK_KEY_CLASS = 354,           /* TOK_KEY_CLASS  */
    TOK_SOCKLOGD_KERNEL = 355,     /* TOK_SOCKLOGD_KERNEL  */
    TOK_SYSLOG_KERNEL = 356,       /* TOK_SYSLOG_KERNEL  */
    TOK_SYSLOG_USER = 357          /* TOK_SYSLOG_USER  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif
/* Token kinds.  */
#define YYEMPTY -2
#define YYEOF 0
#define YYerror 256
#define YYUNDEF 257
#define TOK_DIGITS 258
#define TOK_TYPE_UNKNOWN 259
#define TOK_QUOTED_STRING 260
#define TOK_ID 261
#define TOK_MODE 262
#define TOK_DMESG_STAMP 263
#define TOK_AUDIT_DIGITS 264
#define TOK_DATE_MONTH 265
#define TOK_DATE 266
#define TOK_TIME 267
#define TOK_HEXSTRING 268
#define TOK_TYPE_OTHER 269
#define TOK_MSG_REST 270
#define TOK_IP_ADDR 271
#define TOK_EQUALS 272
#define TOK_COLON 273
#define TOK_MINUS 274
#define TOK_OPEN_PAREN 275
#define TOK_CLOSE_PAREN 276
#define TOK_PERIOD 277
#define TOK_QUESTION_MARK 278
#define TOK_SINGLE_QUOTE 279
#define TOK_NONE 280
#define TOK_TYPE_REJECT 281
#define TOK_TYPE_AUDIT 282
#define TOK_TYPE_COMPLAIN 283
#define TOK_TYPE_HINT 284
#define TOK_TYPE_STATUS 285
#define TOK_TYPE_ERROR 286
#define TOK_TYPE_AA_REJECT 287
#define TOK_TYPE_AA_AUDIT 288
#define TOK_TYPE_AA_COMPLAIN 289
#define TOK_TYPE_AA_HINT 290
#define TOK_TYPE_AA_STATUS 291
#define TOK_TYPE_AA_ERROR 292
#define TOK_TYPE_LSM_AVC 293
#define TOK_TYPE_USER_AVC 294
#define TOK_KEY_APPARMOR 295
#define TOK_KEY_TYPE 296
#define TOK_KEY_MSG 297
#define TOK_KEY_OPERATION 298
#define TOK_KEY_NAME 299
#define TOK_KEY_NAME2 300
#define TOK_KEY_MASK 301
#define TOK_KEY_DENIED_MASK 302
#define TOK_KEY_REQUESTED_MASK 303
#define TOK_KEY_ATTRIBUTE 304
#define TOK_KEY_TASK 305
#define TOK_KEY_PARENT 306
#define TOK_KEY_MAGIC_TOKEN 307
#define TOK_KEY_INFO 308
#define TOK_KEY_PEER_INFO 309
#define TOK_KEY_PID 310
#define TOK_KEY_PEER_PID 311
#define TOK_KEY_PROFILE 312
#define TOK_KEY_PEER_PROFILE 313
#define TOK_KEY_LABEL 314
#define TOK_KEY_PEER_LABEL 315
#define TOK_KEY_PEER 316
#define TOK_AUDIT 317
#define TOK_KEY_FAMILY 318
#define TOK_KEY_SOCK_TYPE 319
#define TOK_KEY_PROTOCOL 320
#define TOK_KEY_NAMESPACE 321
#define TOK_KEY_ERROR 322
#define TOK_KEY_FSUID 323
#define TOK_KEY_FSUID_UPPER 324
#define TOK_KEY_OUID 325
#define TOK_KEY_OUID_UPPER 326
#define TOK_KEY_UID 327
#define TOK_KEY_AUID 328
#define TOK_KEY_SAUID 329
#define TOK_KEY_SES 330
#define TOK_KEY_HOSTNAME 331
#define TOK_KEY_ADDR 332
#define TOK_KEY_TERMINAL 333
#define TOK_KEY_EXE 334
#define TOK_KEY_COMM 335
#define TOK_KEY_CAPABILITY 336
#define TOK_KEY_CAPNAME 337
#define TOK_KEY_OFFSET 338
#define TOK_KEY_TARGET 339
#define TOK_KEY_LADDR 340
#define TOK_KEY_FADDR 341
#define TOK_KEY_LPORT 342
#define TOK_KEY_FPORT 343
#define TOK_KEY_BUS 344
#define TOK_KEY_PATH 345
#define TOK_KEY_INTERFACE 346
#define TOK_KEY_MEMBER 347
#define TOK_KEY_SIGNAL 348
#define TOK_KEY_FSTYPE 349
#define TOK_KEY_FLAGS 350
#define TOK_KEY_SRCNAME 351
#define TOK_KEY_UNIX_PEER_ADDR 352
#define TOK_KEY_EXECPATH 353
#define TOK_KEY_CLASS 354
#define TOK_SOCKLOGD_KERNEL 355
#define TOK_SYSLOG_KERNEL 356
#define TOK_SYSLOG_USER 357

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 94 "grammar.y"

	char	*t_str;
	long	t_long;

#line 282 "grammar.h"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif




int aalogparse_parse (void *scanner, aa_log_record *ret_record);


#endif /* !YY_AALOGPARSE_GRAMMAR_H_INCLUDED  */
